"""Module for generating greeting messages."""


def say_hello(name: str) -> str:
    """
    Returns a greeting message for the given name.

    :param name: The name of the person to greet.
    :return: A greeting string.
    """
    return f"Hello, {name}!"
